import React, { useState, useEffect } from 'react';
import axios from 'axios';

const Posts = () => {
  const [posts, setPosts] = useState([]);
  const [text, setText] = useState('');
  const [media, setMedia] = useState('');
  const [mediaType, setMediaType] = useState('');
  const [code, setCode] = useState('');

  const axiosInstance = axios.create({
    baseURL: 'http://localhost:3000',
    headers: {
      Authorization: process.env.REACT_APP_SERVICE_TOKEN,
    },
  });

  useEffect(() => {
    fetchPosts();
  }, []);

  const fetchPosts = async () => {
    try {
      const response = await axiosInstance.get('/posts');
      setPosts(response.data);
    } catch (error) {
      console.error('Error fetching posts:', error);
    }
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      const newPost = { text, media, mediaType, code };
      await axiosInstance.post('/posts', newPost);
      fetchPosts(); // Обновляем список постов после создания нового
      setText('');
      setMedia('');
      setMediaType('');
      setCode('');
    } catch (error) {
      console.error('Error creating post:', error);
    }
  };

  return (
    <div>
      <h1>Posts</h1>
      <form onSubmit={handleSubmit}>
        <input
          type="text"
          placeholder="Text"
          value={text}
          onChange={(e) => setText(e.target.value)}
        />
        <input
          type="text"
          placeholder="Media URL"
          value={media}
          onChange={(e) => setMedia(e.target.value)}
        />
        <input
          type="text"
          placeholder="Media Type"
          value={mediaType}
          onChange={(e) => setMediaType(e.target.value)}
        />
        <input
          type="text"
          placeholder="Code"
          value={code}
          onChange={(e) => setCode(e.target.value)}
        />
        <button type="submit">Create Post</button>
      </form>
      <h2>All Posts</h2>
      <ul>
        {posts.map((post, index) => (
          <li key={index}>
            <p>{post.text}</p>
            {post.media && <img src={post.media} alt="Post media" />}
            <p>Media Type: {post.mediaType}</p>
            <p>Code: {post.code}</p>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default Posts;
